@@ -1,7 +1,7 @@
 package Huawei::Healthchecker;
 
 #版本信息
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 use 5.012;
 use warnings;
@@ -706,7 +706,7 @@ sub cpu_status {
 
             #写入异常状态
             $result->{"log"}
-                = "CPU利用率超出当前阈值： " . "$info[1]"
+                = "CPU利用率超出当前阈值： " . "$usage\%"
                 if $usage >= $cpu_threshold;
 
             #设置越线惩罚机制
@@ -743,7 +743,7 @@ sub cpu_status {
 
             #写入异常状态
             $result->{"log"}
-                = "CPU历史最大利用率超出阈值：" . "$info[1]"
+                = "CPU历史最大利用率超出阈值：" . "$max_usage\%"
                 if $max_usage > $cpu_max_threshold;
 
             $result->{"alarm"} = "critic" if $max_usage > $cpu_max_threshold;
@@ -801,7 +801,7 @@ sub memory_status {
 
             #写入异常状态
             $result->{"log"}
-                = "内存利用率超出当前阈值：" . $info[1]
+                = "内存利用率超出当前阈值：" . "$usage\%"
                 if ( $usage > $memory_threshold );
 
             #设置越线惩罚机制
@@ -1046,3 +1046,4 @@ sub err_down_status {
 }
 
 1;
+
